@@ -1,7 +1,7 @@
 # -*- coding: UTF-8 -*-
 '''
 @作者  ：B站/抖音/微博/小红书/公众号，都叫：程序员晚枫
-@微信     ：CoderWanFeng : https://mp.weixin.qq.com/s/B1V6KeXc7IOEB8DgXLWv3g
+@微信     ：CoderWanFeng : https://mp.weixin.qq.com/s/Nt8E8vC-ZsoN1McTOYbY2g
 @个人网站      ：www.python-office.com
 @代码日期    ：2023/8/22 23:28
 '''
@@ -23,7 +23,7 @@ def image2gif():
 # todo：输出文件路径
 # @except_dec()
 @instruction
-def add_watermark(file, mark, output_path='./mark_img', color="#8B8B1B", size=50, opacity=0.02, space=200,
+def add_watermark(file, mark, output_path='./', color="#eaeaea", size=30, opacity=0.35, space=200,
                   angle=30):
     """
     给图片加水印
@@ -78,6 +78,7 @@ def decode_qrcode(qrcode_path):
     """
     poimage.decode_qrcode(qrcode_path)
 
+
 @instruction
 def del_watermark(input_image, output_image=r'./del_water_mark.jpg'):
     poimage.del_watermark(input_image, output_image)
